summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 18:53:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-07 18:53:43 -0600
commit977b943aa9e3c96ace9b8e5828a48ca3abee5260 (patch)
treef736a11a59ed4eeb61fca1c8eae43417eb161592
parent2ceaddf9ddadca2d7de8413759f2fee4a48e3936 (diff)
downloadarts-977b943a.tar.gz
arts-977b943a.zip
Rename KDEHOME and KDEDIR
-rw-r--r--doc/README2
-rw-r--r--mcop/mcoputils.cc8
2 files changed, 5 insertions, 5 deletions
diff --git a/doc/README b/doc/README
index 1d81e8b..3193d81 100644
--- a/doc/README
+++ b/doc/README
@@ -1,5 +1,5 @@
All of the aRts documentation is now in "The aRts Handbook" which is
in KDE DocBook format, part of tdemultimedia. It should be found on a
-KDE system in $KDEDIR/share/doc/HTML/default/artsbuilder/index.html.
+KDE system in $TDEDIR/share/doc/HTML/default/artsbuilder/index.html.
An on-line version can be found at http://www.arts-project.org/doc/handbook
diff --git a/mcop/mcoputils.cc b/mcop/mcoputils.cc
index c935d10..6f108b3 100644
--- a/mcop/mcoputils.cc
+++ b/mcop/mcoputils.cc
@@ -83,7 +83,7 @@ static char *locate_mcop_dir()
string user_tmp_dir;
int uid = getuid();
const char *home_dir = getenv("HOME");
- const char *kde_home = uid ? getenv("KDEHOME") : getenv("KDEROOTHOME");
+ const char *kde_home = uid ? getenv("TDEHOME") : getenv("KDEROOTHOME");
const char *kde_prefix = "/socket-";
const char *tmp;
char *tmp_buf;
@@ -151,7 +151,7 @@ static char *locate_mcop_dir()
result = lstat(kde_tmp_dir.c_str(), &stat_buf);
if ((result == 0) && (S_ISDIR(stat_buf.st_mode)))
{
/* $KDEHOME/socket-$HOSTNAME is a normal directory. Do nothing. */
tmp_buf = strdup(kde_tmp_dir.c_str());
return tmp_buf;
}
@@ -231,7 +231,7 @@ int build_link(string tmp_prefix, const char *kde_prefix)
char *tmp_buf;
int uid = getuid();
const char *home_dir = getenv("HOME");
- const char *kde_home = uid ? getenv("KDEHOME") : getenv("KDEROOTHOME");
+ const char *kde_home = uid ? getenv("TDEHOME") : getenv("KDEROOTHOME");
int result;
struct stat stat_buf;
@@ -295,7 +295,7 @@ int build_link(string tmp_prefix, const char *kde_prefix)
result = lstat(kde_tmp_dir.c_str(), &stat_buf);
if ((result == 0) && (S_ISDIR(stat_buf.st_mode)))
{
/* $KDEHOME/tmp is a normal directory. Do nothing. */
printf("Directory \"%s\" already exists.\n", kde_tmp_dir.c_str());
return 0;
}
@@ -151,7 +151,7 @@ static char *locate_mcop_dir()
if ((result == 0) && (S_ISDIR(stat_buf.st_mode)))
{
- /* $KDEHOME/socket-$HOSTNAME is a normal directory. Do nothing. */
+ /* $TDEHOME/socket-$HOSTNAME is a normal directory. Do nothing. */
tmp_buf = strdup(kde_tmp_dir.c_str());
return tmp_buf;
@@ -295,7 +295,7 @@ int build_link(string tmp_prefix, const char *kde_prefix)
if ((result == 0) && (S_ISDIR(stat_buf.st_mode)))
{
- /* $KDEHOME/tmp is a normal directory. Do nothing. */
+ /* $TDEHOME/tmp is a normal directory. Do nothing. */
printf("Directory \"%s\" already exists.\n", kde_tmp_dir.c_str());
return 0;